VOL-569: Create kubernetes deployment configuration for each voltha service

This update:
- organizes all Voltha components under their own namespace, "voltha". If
  you have a script for deploying Voltha, then add namespace.yml at the top.
- adds host volume mounts for Consul's data and config directories
- fixes a bug in Envoy where it was aborting because it couldn't find Consul
  even though it was getting the Voltha assignments from Etcd.

Change-Id: I45eaf2d65428c0184df06971ce3797b9122d3055
diff --git a/envoy/go/envoyd/envoyd.go b/envoy/go/envoyd/envoyd.go
index 6523c90..b1a4067 100644
--- a/envoy/go/envoyd/envoyd.go
+++ b/envoy/go/envoyd/envoyd.go
@@ -145,7 +145,7 @@
 		time.Sleep(time.Duration(ec.waitTime) * time.Second)
 	}
 	if err != nil {
-		log.Printf("%s name resolution failed %d times gving up", serviceName, ec.retries)
+		log.Printf("%s name resolution failed %d times giving up", serviceName, ec.retries)
 	}
 	return
 }
@@ -623,9 +623,9 @@
 }
 
 func (ec * EnvoyControl) Initialize() (err error) {
-	// Resolve consul's virtual ip address
-	if err = ec.resolveServiceAddress(ec.consulSvcName); err != nil {
-		log.Fatal("Can't proceed without consul's vIP address: %s", err.Error())
+	// Resolve KV store's virtual ip address
+	if err = ec.resolveServiceAddress(ec.kvSvcName); err != nil {
+		log.Fatal("Can't proceed without KV store's vIP address: %s", err.Error())
 	}
 
 	// Resolve voltha's virtual ip address
@@ -638,7 +638,7 @@
 	}
 
 	if ec.httpDisabled == true && ec.httpsDisabled == true {
-		log.Printf("Cowardly refusing to disable both http and https, leavign them both enabled\n")
+		log.Printf("Cowardly refusing to disable both http and https, leaving them both enabled\n")
 	} else if ec.httpDisabled == true {
 		log.Printf("Diasabling http\n")
 		ec.envoyConfigTemplate = ec.envoyConfigTemplateNoHttp
@@ -663,7 +663,7 @@
 	log.Printf("KV-store %s at %s:%s", ec.kvStore, ec.kvSvcName, ec.kvPort)
 
 	if err = ec.Initialize(); err != nil {
-		log.Fatal("Envoy control initialization failed, aboring: %s", err.Error())
+		log.Fatal("Envoy control initialization failed, aborting: %s", err.Error())
 	}